summaryrefslogtreecommitdiff
path: root/MdePkg/Library/UefiPciSegmentLibPciRootBridgeIo
diff options
context:
space:
mode:
authorqhuang8 <qhuang8@6f19259b-4bc3-4df7-8a09-765794883524>2010-02-01 02:48:17 +0000
committerqhuang8 <qhuang8@6f19259b-4bc3-4df7-8a09-765794883524>2010-02-01 02:48:17 +0000
commita0720bb82b1d4cd62ed3cfba30264c6c56d24217 (patch)
tree4bc57d7e0b9a42efaca0c94619a13b93488c9fbb /MdePkg/Library/UefiPciSegmentLibPciRootBridgeIo
parent9fddf05b7e4e93a5e49d3195ada27552beff6c73 (diff)
downloadedk2-platforms-a0720bb82b1d4cd62ed3cfba30264c6c56d24217.tar.xz
Add missing dependency expression for some library instances in MdePkg
git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@9891 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'MdePkg/Library/UefiPciSegmentLibPciRootBridgeIo')
-rw-r--r--MdePkg/Library/UefiPciSegmentLibPciRootBridgeIo/PciSegmentLib.c6
-rw-r--r--MdePkg/Library/UefiPciSegmentLibPciRootBridgeIo/UefiPciSegmentLibPciRootBridgeIo.inf4
2 files changed, 6 insertions, 4 deletions
diff --git a/MdePkg/Library/UefiPciSegmentLibPciRootBridgeIo/UefiPciSegmentLibPciRootBridgeIo.inf b/MdePkg/Library/UefiPciSegmentLibPciRootBridgeIo/UefiPciSegmentLibPciRootBridgeIo.inf
index 8aba36b3b3..59a0d4dbc4 100644
--- a/MdePkg/Library/UefiPciSegmentLibPciRootBridgeIo/UefiPciSegmentLibPciRootBridgeIo.inf
+++ b/MdePkg/Library/UefiPciSegmentLibPciRootBridgeIo/UefiPciSegmentLibPciRootBridgeIo.inf
@@ -7,7 +7,7 @@
# This library binds to all of the PCI Root Bridge I/O Protocols in the platform and handles
# the translation from a PCI segment number into a specific PCI Root Bridge I/O Protocol.
#
-# Copyright (c) 2007 - 2008, Intel Corporation.
+# Copyright (c) 2007 - 2010, Intel Corporation.
#
# All rights reserved. This program and the accompanying materials
# are licensed and made available under the terms and conditions of the BSD License
@@ -54,3 +54,5 @@
[Protocols]
gEfiPciRootBridgeIoProtocolGuid ## CONSUMES
+[Depex]
+ gEfiPciRootBridgeIoProtocolGuid
diff --git a/MdePkg/Library/UefiPciSegmentLibPciRootBridgeIo/PciSegmentLib.c b/MdePkg/Library/UefiPciSegmentLibPciRootBridgeIo/PciSegmentLib.c
index da153f994a..fa6f3ea02e 100644
--- a/MdePkg/Library/UefiPciSegmentLibPciRootBridgeIo/PciSegmentLib.c
+++ b/MdePkg/Library/UefiPciSegmentLibPciRootBridgeIo/PciSegmentLib.c
@@ -1,7 +1,7 @@
/** @file
PCI Segment Library implementation using PCI Root Bridge I/O Protocol.
- Copyright (c) 2007 - 2009, Intel Corporation All rights
+ Copyright (c) 2007 - 2010, Intel Corporation All rights
reserved. This program and the accompanying materials are
licensed and made available under the terms and conditions of
the BSD License which accompanies this distribution. The full
@@ -16,13 +16,13 @@
#include "PciSegmentLib.h"
//
// Global varible to record data of PCI Root Bridge I/O Protcol instances
//
PCI_ROOT_BRIDGE_DATA *mPciRootBridgeData = NULL;
UINTN mNumberOfPciRootBridges = 0;
/**
- The constructor function caches data of PCI Root Bridge I/O Protcol instances.
+ The constructor function caches data of PCI Root Bridge I/O Protocol instances.
The constructor function locates PCI Root Bridge I/O protocol instances,
and caches the protocol instances, together with their segment numbers and bus ranges.
@@ -16,13 +16,13 @@
#include "PciSegmentLib.h"
//
-// Global varible to record data of PCI Root Bridge I/O Protcol instances
+// Global variable to record data of PCI Root Bridge I/O Protocol instances
//
PCI_ROOT_BRIDGE_DATA *mPciRootBridgeData = NULL;